@@ -1,4 +1,5 @@
 """Landroid Cloud statistics class."""
+from __future__ import annotations
 
 from .landroid_class import LDict
 
@@ -6,7 +7,7 @@ from .landroid_class import LDict
 class Statistic(LDict):
     """Statistics."""
 
-    def __init__(self, data: list = None):
+    def __init__(self, data: list | None = None) -> dict:
         """Initialize a statistics class."""
         super().__init__()
 
